==> lxqt-admin_0.14.1.orig.tar.xz: lxqt-admin-0.14.1/lxqt-admin-time/translations/lxqt-admin-time_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>日期:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>開啟網路時間同步（NTP）</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC 與本地時間同步</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <source>lxqt-admin-time-helper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>時間與日期設定</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>日期與時間</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>時區</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="120"/>
        <location filename="../timeadmindialog.cpp" line="130"/>
        <location filename="../timeadmindialog.cpp" line="137"/>
        <location filename="../timeadmindialog.cpp" line="147"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="155"/>
        <source>Reboot required</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>你的當前時區:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>過濾器</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
</TS>

==> lxqt-admin_0.16.0.orig.tar.xz: lxqt-admin-0.16.0/lxqt-admin-time/translations/lxqt-admin-time_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>日期:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>開啟網路時間同步（NTP）</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC 與本地時間同步</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <source>lxqt-admin-time-helper</source>
        <translation>LXQT時間管理助手</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;活動(%1)失敗&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>時間與日期設定</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>日期與時間</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>時區</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="120"/>
        <location filename="../timeadmindialog.cpp" line="130"/>
        <location filename="../timeadmindialog.cpp" line="137"/>
        <location filename="../timeadmindialog.cpp" line="147"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>變更RTC為本地時間需要重新啓動</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>變更RTC為UTC時間需要重新啓動</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="155"/>
        <source>Reboot required</source>
        <translation>需要重新啓動</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>你的當前時區:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>過濾器</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
</TS>
